@@ -9,10 +9,10 @@ WebService::CDNetworks::Purge - A client for the CDNetworks's Cache Flush Open A
 
 =head1 SYNOPSIS
 
-	my $service = WebService::CDNetworks::Purge -> new({
+	my $service = WebService::CDNetworks::Purge -> new(
 		'username' => 'xxxxxxxx',
 		'password' => 'yyyyyyyy',
-	});
+	);
 
 	my $listOfPADs = $service -> listPADs();
 
@@ -22,7 +22,7 @@ WebService::CDNetworks::Purge - A client for the CDNetworks's Cache Flush Open A
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use Carp;
 use Try::Tiny;
@@ -110,13 +110,9 @@ sub listPADs {
 
 }
 
-=head2 _purgeItems
-
-Description: private method used to purge a single chunk of paths from cache
-Parameters: PAD/domain and an arrayref with the list of paths to purge
-Returns: A hash ref with the parsed JSON response from service
-
-=cut
+# Description: private method used to purge a single chunk of paths from cache
+# Parameters: PAD/domain and an arrayref with the list of paths to purge
+# Returns: A hash ref with the parsed JSON response from service
 
 sub _purgeItems {
 
